# CumulusCI Diagram Presentation

This directory contains the diagram presentation from the Automating the Impossible: End to End Team Development for ISV's session at Dreamforce 14.  To run the presentation on your local computer:

1. Clone the CumulusCI repository
2. Install the docs/diagram/octicons.ttf font on your computer
3. Load docs/diagram/index.html in your browser
4. Use left/right arrow keys to navigate through the presentation
